@@ -3,6 +3,7 @@ import requests
 
 def chat(value):
 	if("sahibin kim" in value):
+		print("kenan")
 		return "Sahibim namıdeğer r4isy."
 	else:
 		translator = Translator()
@@ -11,8 +12,9 @@ def chat(value):
 		veri = response.text.split(':"')[-1].split('"}')[0]
 		translated = translator.translate(veri, dest="tr")
 		if("zackybot" in translated.text):
-			new_string = string.replace("ZackyBot", "kenu-ai")
+			new_string = "Adım, kenu-ai. r4isy tarafından yazıldım."
 			return new_string
+		elif("Accobot" in translated.text):
+			return "Sahibim namıdeğer r4isy."
 		else:
-			return translated.text
-
+			return translated.text
\ No newline at end of file
